@@ -128,12 +128,14 @@ mod tests {
 
         #[derive(Clone)]
         pub struct TypeA {
+            #[allow(dead_code)]
             value: std::rc::Rc<f64>,
         }
 
         #[allow(clippy::redundant_allocation)]
         #[derive(Clone)]
         pub struct TypeB {
+            #[allow(dead_code)]
             value: std::rc::Rc<std::rc::Rc<f64>>,
         }
 
@@ -166,9 +168,7 @@ mod tests {
             }
             .into_any();
 
-            let y: Option<&TypeA> = AnyLike::as_inner(&x);
-
-            drop(y.clone());
+            let _: Option<&TypeA> = AnyLike::as_inner(&x);
         }
     }
 
@@ -177,6 +177,7 @@ mod tests {
 
         #[derive(Clone)]
         pub struct Type {
+            #[allow(dead_code)]
             value: f64,
         }
 
