@@ -3,7 +3,7 @@ use crate::type_information;
 use std::{cmp::max, str::from_utf8_unchecked};
 
 #[repr(C)]
-#[derive(Clone, Debug)]
+#[derive(Clone, Debug, Default)]
 pub struct ByteString {
     buffer: ArcBuffer,
 }
@@ -71,16 +71,6 @@ impl ByteString {
     }
 }
 
-unsafe impl Sync for ByteString {}
-
-impl Default for ByteString {
-    fn default() -> Self {
-        Self {
-            buffer: ArcBuffer::new(0),
-        }
-    }
-}
-
 impl PartialEq for ByteString {
     fn eq(&self, other: &ByteString) -> bool {
         self.as_slice() == other.as_slice()
